@@ -12,11 +12,11 @@ from typing import List
 # 但是单个脚本还是有用的所以我会将这些代码再复制一遍成一个单个脚本
 from Annotations2Sub.Annotation import Annotation
 from Annotations2Sub.Color import Alpha, Color
-from Annotations2Sub.Sub import Draw, Event, DrawCommand
 from Annotations2Sub.internationalization import _
-from Annotations2Sub.flag import Flags
+from Annotations2Sub.Sub import Draw, DrawCommand, Event
 from Annotations2Sub.tools import Stderr
 
+
 # 这些代码实际上来自于
 # https://github.com/USED255/Annotations2Sub/blob/f20f9fe90e0e63b005e8120085539817b49c5296/Annotations2Sub.py
 def Convert(
@@ -65,7 +65,8 @@ def Convert(
             tag += r"\an7" + r"\pos({},{})".format(x + 1, y + 1)
             # "\fs<字体尺寸>"
             # "<字体尺寸> 是一个数字，指定了字体的点的尺寸。"
-            # "注意，这里的字体尺寸并不是字号的大小，\fs20 并不是字体大小（font-size）为 20px，而是指其行高（line-height）为 20px，主要归咎于 VSFilter 使用的 Windows GDI 的字体接口。"
+            # "注意，这里的字体尺寸并不是字号的大小，\fs20 并不是字体大小（font-size）为 20px，
+            # 而是指其行高（line-height）为 20px，主要归咎于 VSFilter 使用的 Windows GDI 的字体接口。"
             # 我没在意这个, 直接用得了
             # 反正效果也没咋差
             tag += r"\fs" + str(textSize)
@@ -139,8 +140,9 @@ def Convert(
             # 很像是我们熟悉的 "字体大小"
             # 但好像又不是
             # / 4 也是试出来的
-            nonlocal textSize  # type: ignore
-            textSize = round(textSize / 4, 3)
+            if resolutionX != 100 and resolutionY != 100:
+                nonlocal textSize  # type: ignore
+                textSize = round(textSize / 4, 3)
 
             event.Name += "_title"
 
@@ -207,6 +209,10 @@ def Convert(
             if sy > y:
                 y1 = y1 + height
 
+            x1 = round(x1, 3)
+            y1 = round(y1, 3)
+            x2 = round(x2, 3)
+
             d = Draw()
             # 一共三个点, 怎么画都是个三角形
             d.Add(DrawCommand(0, 0, "m"))
@@ -278,7 +284,7 @@ def Convert(
             events.append(popup_box(copy.copy(event)))
         elif each.style == "title":
             events.append(title(copy.copy(event)))
-        elif each.style == "highlightText" and Flags.unstable:
+        elif each.style == "highlightText":
             # 我还没遇到过 highlightText, 所以实现很可能不对
             events.append(highlightText_text(copy.copy(event)))
             events.append(highlightText_box(copy.copy(event)))
@@ -287,6 +293,10 @@ def Convert(
             events.append(speech_text(copy.copy(event)))
             events.append(speech_box(copy.copy(event)))
             events.append(speech_box_2(copy.copy(event)))
+        elif each.style == "anchored":
+            events.append(speech_text(copy.copy(event)))
+            events.append(speech_box(copy.copy(event)))
+            events.append(speech_box_2(copy.copy(event)))
         else:
             # 传承于 Annotations2Sub™
             Stderr(_("不支持 {} 样式 ({})").format(each.style, each.id))
