@@ -3,13 +3,13 @@
 
 """程序入口"""
 
+import _thread
 import argparse
 import os
 import re
 import sys
 import traceback
 import urllib.request
-import _thread
 
 # 我觉得在输入确定的环境下用不着这玩意
 # 不过打包到了 PyPI 也不用像以前那些忌惮第三方库了
@@ -17,36 +17,30 @@ import _thread
 import defusedxml.ElementTree  # type: ignore
 
 from Annotations2Sub import version
-from Annotations2Sub.flag import Flags
 from Annotations2Sub.Annotation import Parse
 from Annotations2Sub.Convert import Convert
-from Annotations2Sub.Sub import Sub
+from Annotations2Sub.flag import Flags
 from Annotations2Sub.internationalization import _
+from Annotations2Sub.Sub import Sub
 from Annotations2Sub.tools import (
     AnnotationsForArchive,
     CheckUrl,
     RedText,
+    Stderr,
     VideoForInvidious,
     YellowText,
-    Stderr,
 )
 
 
 def main():
     """程序入口"""
-    parser = argparse.ArgumentParser(
-        description=_(
-            "一个可以把 Youtube Annotation 转换成 ASS 字幕(Advanced SubStation Alpha)文件的脚本"
-        )
-    )
+    parser = argparse.ArgumentParser(description=_("下载和转换 Youtube 注释"))
     parser.add_argument(
         "queue",
         type=str,
         nargs="+",
         metavar=_("文件 或 videoId"),
-        help=_(
-            "多个需要转换的文件的文件路径, 或者是多个需要预览, 生成, 从Internet Archive 下载注释文件 Youtube 视频的 videoId"
-        ),
+        help=_("多个需要转换的文件的文件路径或视频ID"),
     )
     parser.add_argument(
         "-l",
@@ -61,7 +55,7 @@ def main():
         "--transform-resolution-x",
         default=100,
         type=int,
-        metavar=100,
+        metavar="100",
         help=_("变换分辨率X"),
     )
     parser.add_argument(
@@ -69,7 +63,7 @@ def main():
         "--transform-resolution-y",
         default=100,
         type=int,
-        metavar=100,
+        metavar="100",
         help=_("变换分辨率Y"),
     )
 
@@ -88,7 +82,12 @@ def main():
         action="store_true",
         help=_("尝试从 Internet Archive 下载注释文件"),
     )
-
+    parser.add_argument(
+        "-D",
+        "--download-annotation-only",
+        action="store_true",
+        help=_("仅下载注释"),
+    )
     # 就是拼接参数执行 mpv
     parser.add_argument(
         "-p",
@@ -124,26 +123,14 @@ def main():
         "-N", "--no-keep-intermediate-files", action="store_true", help=_("不保留中间文件")
     )
 
-    # 其实我觉得这个选项应该没啥用
     parser.add_argument(
         "-o",
         "--output-directory",
         type=str,
-        metavar=_("文件夹"),
-        help=_("指定转换后文件的输出路径, 不指定此选项转换后的文件会输出至与被转换文件同一目录"),
+        metavar=_("目录"),
+        help=_("指定转换后文件的输出目录"),
     )
     parser.add_argument("-O", "--output", type=str, metavar=_("文件"), help=_("保存到此文件"))
-    parser.add_argument(
-        "-S", "--skip-invalid-files", action="store_true", help=_("跳过无效文件")
-    )
-
-    # 可能是用来甩锅用的
-    parser.add_argument(
-        "-u",
-        "--unstable",
-        action="store_true",
-        help=_("启用不稳定功能, 会出现一些问题"),
-    )
     parser.add_argument(
         "-v",
         "--version",
@@ -152,43 +139,54 @@ def main():
         version=_("Annotations2Sub v{version}").format(version=version),
     )
 
-    # 这个好像不是用来调试用的
+    # 这个不是用来调试用的
     parser.add_argument(
         "-V",
         "--verbose",
         action="store_true",
-        help=_("显示更多些消息"),
+        help=_("显示更多消息"),
     )
 
     args = parser.parse_args()
 
-    filePaths = []
-
-    if args.unstable:
-        Flags.unstable = True
-
     if args.verbose:
         Flags.verbose = True
 
     if args.output_to_stdout:
         if args.output_directory is not None:
-            Stderr(RedText(_("--output-to-stdout 与 --output-directory 选项相斥")))
+            Stderr(RedText(_("--output-to-stdout 不能与 --output-directory 选项同时使用")))
             exit(1)
         if args.no_overwrite_files:
-            Stderr(RedText(_("--output-to-stdout 与 --no-overwrite-files 选项相斥")))
+            Stderr(RedText(_("--output-to-stdout 不能与 --no-overwrite-files 选项同时使用")))
             exit(1)
         if args.output is not None:
-            Stderr(RedText(_("--output-to-stdout 与 --output 选项相斥")))
+            Stderr(RedText(_("--output-to-stdout 不能与 --output 选项同时使用")))
+            exit(1)
+        if args.download_annotation_only:
+            Stderr(
+                RedText(_("--output-to-stdout 不能与 --download-annotation-only 选项同时使用"))
+            )
             exit(1)
         if args.preview_video or args.generate_video:
             Stderr(
                 RedText(
-                    _("--output-to-stdout 与 --preview-video 或 --generate-video 选项相斥")
+                    _(
+                        "--output-to-stdout 不能与 --preview-video 或 --generate-video 选项同时使用"
+                    )
                 )
             )
             exit(1)
 
     if args.no_keep_intermediate_files:
+        if args.download_annotation_only:
+            Stderr(
+                RedText(
+                    _(
+                        "--no-keep-intermediate-files 不能与 --download-annotation-only 选项同时使用"
+                    )
+                )
+            )
+            exit(1)
         if not (args.download_for_archive or args.preview_video or args.generate_video):
             Stderr(
                 RedText(
@@ -199,19 +197,19 @@ def main():
             )
             exit(1)
 
-    if args.output_directory is not None:
-        if os.path.isdir(args.output_directory) is False:
-            Stderr(RedText(_("转换后文件的输出路径应该指定一个文件夹")))
-            exit(1)
-
     if args.output is not None:
         if args.output_directory is not None:
-            Stderr(RedText(_("--output 与 --output--directory 选项相斥")))
+            Stderr(RedText(_("--output 不能与 --output--directory 选项同时使用")))
             exit(1)
         if len(args.queue) > 1:
             Stderr(RedText(_("--output 只能处理一个文件")))
             exit(1)
 
+    if args.output_directory is not None:
+        if os.path.isdir(args.output_directory) is False:
+            Stderr(RedText(_("转换后文件输出目录应该指定一个文件夹")))
+            exit(1)
+
     if args.preview_video or args.generate_video:
         if args.invidious_instances is None:
             Stderr(RedText(_("请指定一个 invidious 实例")))
@@ -226,11 +224,14 @@ def main():
         Stderr(
             YellowText(
                 _(
-                    "--embrace-libass 需要注意, 如果您的视频不是 16:9, 请使用 --transform-resolution-x --transform-resolution-y, 以确保效果."
+                    "如果您的视频不是 16:9, 请使用 --transform-resolution-x --transform-resolution-y, 以确保效果"
                 )
             )
         )
 
+    if args.download_annotation_only:
+        args.download_for_archive = True
+
     if args.download_for_archive:
         # 省的网不好不知道
         def CheckNetwork():
@@ -239,76 +240,72 @@ def main():
 
         _thread.start_new_thread(CheckNetwork, ())
 
-        videoIds = []
-        queue = []
-        for videoId in args.queue:
-            # 先查一遍
+    for Task in args.queue:
+        videoId = Task
+        annotationFile = Task
+        if args.download_for_archive:
             if re.match(r"[a-zA-Z0-9_-]{11}", videoId) is None:
                 Stderr(RedText(_("{} 不是一个有效的视频 ID").format(videoId)))
-                exit(1)
-            videoIds.append(videoId)
-        for videoId in videoIds:
-            filePath = f"{videoId}.xml"
+                continue
+
+            annotationFile = f"{videoId}.xml"
+            if args.download_annotation_only and args.output:
+                annotationFile = args.output
             if args.output_directory is not None:
-                filePath = os.path.join(args.output_directory, filePath)
-            # 为了显示个 "下载 ", 我把下载从 AnnotationsForArchive 里拆出来了
-            # 之前就直接下载了, 但是我还是更喜欢输出确定且可控
-            url = AnnotationsForArchive(videoId)
-            Stderr(_("下载 {}").format(url))
-            string = urllib.request.urlopen(url).read().decode("utf-8")
-            if string == "":
-                Stderr(YellowText(_("{} 可能没有 Annotation").format(videoId)))
-                continue
-            with open(filePath, "w", encoding="utf-8") as f:
-                f.write(string)
-            queue.append(filePath)
+                annotationFile = os.path.join(args.output_directory, annotationFile)
 
-    if not args.download_for_archive:
-        queue = args.queue
+            skipDownload = False
+            if args.no_overwrite_files and os.path.exists(annotationFile):
+                if os.path.exists(annotationFile):
+                    Stderr(YellowText(_("文件已存在, 跳过下载 ({})").format(videoId)))
+                    skipDownload = True
+            if not skipDownload:
+                url = AnnotationsForArchive(videoId)
+                Stderr(_("下载 {}").format(url))
+                with urllib.request.urlopen(url) as r:
+                    string = r.read().decode("utf-8")
+                with open(annotationFile, "w", encoding="utf-8") as f:
+                    f.write(string)
 
-    for filePath in queue:
-        # 先看看是不是文件
-        if os.path.isfile(filePath) is False:
-            Stderr(RedText(_("{} 不是一个文件").format(filePath)))
-            if args.skip_invalid_files:
+            if args.download_annotation_only:
                 continue
-            exit(1)
-        # 再看看有没有文件无效的
+
+        if os.path.isfile(annotationFile) is False:
+            Stderr(RedText(_("{} 不是一个文件").format(annotationFile)))
+            continue
+
+        with open(annotationFile, "r", encoding="utf-8") as f:
+            annotationsString = f.read()
+
+        if annotationsString == "":
+            Stderr(YellowText(_("{} 可能没有 Annotation").format(Task)))
+            continue
+
         try:
-            tree = defusedxml.ElementTree.parse(filePath)
+            tree = defusedxml.ElementTree.parse(annotationFile)
         except:
-            Stderr(RedText(_("{} 不是一个有效的 XML 文件").format(filePath)))
-            Stderr(traceback.format_exc())
-            if args.skip_invalid_files:
-                continue
-            exit(1)
-        # 再看看有没有不是 Annotation 文件的
+            Stderr(RedText(_("{} 不是一个有效的 XML 文件").format(annotationFile)))
+            if Flags.verbose:
+                Stderr(traceback.format_exc())
+            continue
+
         if tree.find("annotations") == None:
-            Stderr(RedText(_("{} 不是 Annotation 文件").format(filePath)))
-            if args.skip_invalid_files:
-                continue
-            exit(1)
-        # 最后看看是不是空的
+            Stderr(RedText(_("{} 不是 Annotation 文件").format(annotationFile)))
+            continue
+
         if len(tree.find("annotations").findall("annotation")) == 0:
-            Stderr(RedText(_("{} 没有 Annotation").format(filePath)))
-            if args.skip_invalid_files:
-                continue
-            exit(1)
-        filePaths.append(filePath)
+            Stderr(YellowText(_("{} 没有 Annotation").format(annotationFile)))
 
-    outputs = []
-    for filePath in filePaths:
-        output = filePath + ".ass"
+        subFile = annotationFile + ".ass"
         if args.output_directory is not None:
-            fileName = os.path.basename(filePath)
+            fileName = os.path.basename(annotationFile)
             fileName = fileName + ".ass"
-            output = os.path.join(args.output_directory, fileName)
+            subFile = os.path.join(args.output_directory, fileName)
         if args.output is not None:
-            output = args.output
+            subFile = args.output
 
-        # 从这里开始就是 __init__.py 开头那个流程图
-        # 其实这才是核心功能, 其他的都是有的没的
-        with open(filePath, "r", encoding="utf-8") as f:
+        # 这里是 __init__.py 开头那个流程图
+        with open(annotationFile, "r", encoding="utf-8") as f:
             string = f.read()
         tree = defusedxml.ElementTree.fromstring(string)
         annotations = Parse(tree)
@@ -319,39 +316,36 @@ def main():
             args.transform_resolution_y,
         )
         if events == []:
-            Stderr(YellowText(_("{} 没有注释被转换").format(filePath)))
+            Stderr(YellowText(_("{} 没有注释被转换").format(annotationFile)))
         # Annotation 是无序的
-        # 按时间重新排列字幕(事件), 主要是为了人类可读
+        # 按时间重新排列字幕事件, 是为了人类可读
         events.sort(key=lambda event: event.Start)
         sub = Sub()
         sub.events.extend(events)
         sub.info["PlayResX"] = args.transform_resolution_x
         sub.info["PlayResY"] = args.transform_resolution_y
-        sub.info["Title"] = filePath
+        sub.info["Title"] = annotationFile
         sub.styles["Default"].Fontname = args.font
         subString = sub.Dump()
         if args.output_to_stdout:
-            output = None
+            subFile = ""
             print(subString, file=sys.stdout)
         if args.no_overwrite_files:
-            if os.path.exists(output):
-                output = None
-                Stderr(YellowText(_("文件已存在, 您选择不覆盖文件, 跳过输出")))
+            if os.path.exists(subFile):
+                Stderr(YellowText(_("文件已存在, 跳过输出 ({})").format(subFile)))
+                subFile = ""
         if args.no_keep_intermediate_files:
-            os.remove(filePath)
-            Stderr(_("删除 {}").format(filePath))
-        if output:
-            with open(output, "w", encoding="utf-8") as f:
+            os.remove(annotationFile)
+            Stderr(_("删除 {}").format(annotationFile))
+        if subFile != "":
+            with open(subFile, "w", encoding="utf-8") as f:
                 f.write(subString)
-            Stderr(_("保存于: {}").format(output))
-            # 为了下面而准备
-            outputs.append(output)
+            Stderr(_("保存于: {}").format(subFile))
 
-    if args.preview_video:
-        for output in outputs:
+        if args.preview_video:
             # 从 Invidious 获取视频流和音频流, 并塞给 mpv, FFmpeg
             video, audio = VideoForInvidious(videoId, args.invidious_instances)
-            cmd = rf'mpv "{video}" --audio-file="{audio}" --sub-file="{output}"'
+            cmd = rf'mpv "{video}" --audio-file="{audio}" --sub-file="{subFile}"'
             if Flags.verbose:
                 Stderr(cmd)
             exit_code = os.system(cmd)
@@ -359,14 +353,12 @@ def main():
                 if exit_code != 0:
                     Stderr(YellowText("exit with {}".format(exit_code)))
             if args.no_keep_intermediate_files:
-                os.remove(output)
-                Stderr(_("删除 {}").format(output))
+                os.remove(subFile)
+                Stderr(_("删除 {}").format(subFile))
 
-    if args.generate_video:
-        for output in outputs:
-            # 同理
+        if args.generate_video:
             video, audio = VideoForInvidious(videoId, args.invidious_instances)
-            cmd = rf'ffmpeg -i "{video}" -i "{audio}" -vf "ass={output}" {output}.mp4'
+            cmd = rf'ffmpeg -i "{video}" -i "{audio}" -vf "ass={subFile}" {subFile}.mp4'
             if Flags.verbose:
                 Stderr(cmd)
             exit_code = os.system(cmd)
@@ -374,5 +366,5 @@ def main():
                 if exit_code != 0:
                     Stderr(YellowText("exit with {}".format(exit_code)))
             if args.no_keep_intermediate_files:
-                os.remove(output)
-                Stderr(_("删除 {}").format(output))
+                os.remove(subFile)
+                Stderr(_("删除 {}").format(subFile))
